/*
** my_class_example.java should provide a basic program structure for a GUI
** program in Java that can be used by the students of the SPIN course if they
** have problems with their code.
**
** First the class name has to be replaced with the name of your class and
** the paint() and run() functions must be adapted to your needs.
*/

/* Importing packages needed. */
import java.awt.Color;
import java.awt.Graphics;
import java.awt.Rectangle;

import javax.swing.JFrame;
import javax.swing.JPanel;

/******************************************************************************
 This is our main class. It extends JPanel so we can use the drawing         
 functions provided by this class.                                          
******************************************************************************/
public class my_class_example extends JPanel {
	/******************************************************************************
	 Define global constants and variables that can be seen by all functions in
	 the class.
	******************************************************************************/

	/* Define global constants, e.g. the window size (in pixels). */
	final static int X_WINDOW_SIZE = 800;
	final static int Y_WINDOW_SIZE = 600;

	/* Upper left corner of the window on our screen. */
	final static int X_WINDOW_LOCATION = 100;
	final static int Y_WINDOW_LOCATION = 100;

	/* Define gobal variables like the X and Y positions of a particle. */
	double X = 0.0;
	double Y = 0.0;

	/* Define max. values for X and Y  to rescale them to the screen in paint(). */
	double X_MAX = 1.0;
	double Y_MAX = 1.0;

	/************************* end global variables ******************************/

	/******************************************************************************
	 The main function is called when we start the program (It has to be static!).
	******************************************************************************/
	public static void main(String[] args) {
		/* Create a new JFrame object which provides a very basic window for the
		 * application. The title can be chosen arbitrarily. */
		JFrame top = new JFrame("My window title");
		
		/* Position and size of the window. */
		top.setBounds(X_WINDOW_LOCATION, Y_WINDOW_LOCATION, X_WINDOW_SIZE, Y_WINDOW_SIZE);

		/* What do we do if we get a close signal? */
		top.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		
		/* Make a new instance of our class my_class_example. */
		my_class_example my_class_instance = new my_class_example();
		
		/* Add the JPanel to the window we created. All graphical output is now
		 * displayed in the window. */
		top.getContentPane().add(my_class_instance);

		/* Make the window visible. */
		top.setVisible(true);

		/* Run the main function run() where we start the simulation. */
		my_class_instance.run();
	}
	/******************************* end main ***********************************/

	/******************************************************************************
	 The function paint() is called whenever the event handler of the program gets
	 a message that tells it to repaint the JPanel (e.g. we have another window
	 that was overlapping with it). It is also exectued when we use the repaint()
	 function somewhere in the code.
	******************************************************************************/
	public void paint(Graphics g) {
		int xs, ys, xs_max, ys_max;
		// clear drawing area
		/* Get the area that we want to redraw. */
		Rectangle bounds = getBounds();

		/* Clear the area (sometimes you might not want this so just comment it if not needed. */
		g.clearRect(bounds.x, bounds.y, bounds.width, bounds.height);

		/* Maybe rescale the variables to the screen size? */
		xs_max = X_WINDOW_SIZE;
		ys_max = Y_WINDOW_SIZE;

		xs = (int)(X/X_MAX)*xs_max;
		ys = (int)(Y/Y_MAX)*ys_max;

		/* Here we do the drawing loop. This part has to be changed for every program. */

		// YOUR CODE COMES HERE
	}
	/****************************** end paint ************************************/

	/******************************************************************************
	 Here all the numerics are implemented. This part has to be changed for every
	 program you write.
	******************************************************************************/
	public void my_function() {
		/* A very simple example of a function we use for our computations. */
		
		// YOUR CODE COMES HERE
	}

	/******************************************************************************
	 The function run() is called from the function main(). Here we implement the
	 main loop that does the actual calculations.
	******************************************************************************/
	public void run() {
		/* First initialize variables (if you did not do it before). */
		X = 0.0;
		Y = 0.0;

		while (true) {
			/* Main loop of the program. */

			// HERE COMES YOUR CODE

			/* Send a paint message to my_class_example to repaint the window. */
			repaint();
				
			/* Short delay so we can see how the program evolves. */
			try {
				Thread.sleep(250);
			} catch (InterruptedException e) {}
		}
	}
	/********************************** end run **********************************/
}
/******************************* end class ***********************************/

